@@ -15,10 +15,15 @@ def find_extensions(name, setup_py):
     return [Extension(*x) for x in ex]
 
 
-def build_py(setup_py):
-    class BuildPy(build_py_orig):
+class build_py(build_py_orig):
 
-        def build_packages(self):
+    def build_packages(self):
+        pass
+
+
+def get_bdist_egg(setup_py):
+    class bdist_egg:
+        def run(self):
             if os.environ.get('NO_CLEAR_ARTIPY') == "1":
                 return
             else:
@@ -29,7 +34,7 @@ def build_py(setup_py):
                         fname.endswith('.c')
                         os.remove(fname)
 
-    return BuildPy
+    return bdist_egg
 
 
 def artipy(dirname, setup_py):
@@ -38,5 +43,5 @@ def artipy(dirname, setup_py):
     else:
         return {
             'ext_modules': cythonize(find_extensions(dirname, setup_py)),
-            'cmdclass': {'build_py': build_py(setup_py)},
+            'cmdclass': {'build_py': build_py, 'bdist_egg': get_bdist_egg(setup_py)},
         }
